﻿using System;
using System.Collections.Generic;

public class EmbeddingLayer
{
    private int inputDim;
    private int embeddingDim;
    private List<List<double>> embeddings;

    public EmbeddingLayer(int inputDim, int embeddingDim)
    {
        this.inputDim = inputDim;
        this.embeddingDim = embeddingDim;

        Random random = new Random();
        embeddings = new List<List<double>>();

        for (int i = 0; i < inputDim; i++)
        {
            List<double> embedding = new List<double>();
            for (int j = 0; j < embeddingDim; j++)
            {
                embedding.Add(random.NextDouble() * 2 - 1);
            }
            embeddings.Add(embedding);
        }
    }

    public List<double> GetEmbedding(int category)
    {
        return embeddings[category];
    }
}

public class Model
{
    private EmbeddingLayer embeddingLayer;

    public Model(int inputDim, int embeddingDim)
    {
        embeddingLayer = new EmbeddingLayer(inputDim, embeddingDim);
    }

    public List<double> Predict(int category)
    {
        return embeddingLayer.GetEmbedding(category);
    }
}

class Embeddings
{
    static void Main()
    {
        int inputDim = 10; // Number of input categories
        int embeddingDim = 5; // Dimensionality of the embeddings

        Model model = new Model(inputDim, embeddingDim);

        int category = 3; // Category for which we want the embedding
        List<double> embedding = model.Predict(category);

        Console.Write("Embedding for category " + category + ": ");
        foreach (double val in embedding)
        {
            Console.Write(val + " ");
        }
        Console.WriteLine();
    }
}
